# MenuTitle: Edit Selection
# -*- coding: utf-8 -*-
__doc__="""
Create a decomposed backup layer of selection and mark with Yellow label.
"""

import copy
from datetime import date

Glyphs.clearLog()

today = date.today().strftime("(%d %b)")

if Font.selectedLayers: # Selection in Edit View
	selectedGlyphs = list()
	for layer in Font.selectedLayers:
		selectedGlyphs.append(layer.parent)
else: # Selection from Font View
	selectedGlyphs = Font.selection

for glyph in selectedGlyphs:
	glyph.color = 3 # Mark with Yellow Label
	newLayers = list()
	for layer in glyph.layers:
		if layer.isMasterLayer or layer.isSpecialLayer:
			newName = layer.name + " " + today
			decomposedLayer = layer.copyDecomposedLayer()
			decomposedLayer.name = newName
			if decomposedLayer.smartComponentPoleMapping: # Reset Smart Glyph Settings
				for axis in glyph.smartComponentAxes:
					decomposedLayer.smartComponentPoleMapping[axis.id] = 0
			newLayers.append(decomposedLayer)
	for newLayer in newLayers:
		glyph.layers.append(newLayer)
